<?php
namespace AustraliaPost\Extensions\Business\API\Wrapper;


class Create_Order_Request {

	const PAYMENT_METHOD_CHARGE_ACCOUNT = 'CHARGE_TO_ACCOUNT';
	const PAYMENT_METHOD_STORED_PAYMENT = 'STORED_PAYMENT';

	/* @var string */
	private $order_reference;
	/* @var string */
	private $payment_method;
	/* @var array */
	private $shipments;
	/* @var array */
	private $pickups = [];

	/**
	 * @return string
	 */
	public function getOrderReference() {
		return $this->order_reference;
	}

	/**
	 * @param string $order_reference
	 *
	 * @return Create_Order_Request
	 */
	public function setOrderReference( $order_reference ) {
		$this->order_reference = $order_reference;

		return $this;
	}

	/**
	 * @return string
	 */
	public function getPaymentMethod() {
		return $this->payment_method;
	}

	/**
	 * @param string $payment_method
	 *
	 * @return Create_Order_Request
	 */
	public function setPaymentMethod( $payment_method ) {
		$this->payment_method = $payment_method;

		return $this;
	}

	/**
	 * @return array
	 */
	public function getShipments() {
		return $this->shipments;
	}

	/**
	 * @param array $shipment
	 *
	 * @return Create_Order_Request
	 */
	public function addShipment( $shipment ) {
		$this->shipments[] = $shipment;

		return $this;
	}

	/**
	 * @return array
	 */
	public function getPickups()
	{
		return $this->pickups;
	}

	/**
	 * @param string $pickupId
	 *
	 * @return $this
	 */
	public function addPickupId(string $pickupId)
	{
		$this->pickups[] = $pickupId;

		return $this;
	}



	public function getPayload()
	{
		$payload = [
			'order_reference' => $this->getOrderReference(),
			'payment_method' => $this->getPaymentMethod(),
		];

		foreach ($this->getShipments() as $shipment) {
			$payload['shipments'][] = ['shipment_id' => $shipment];
		}

		foreach ($this->getPickups() as $pickupId) {
			$payload['pickups'][] = ['pickup_id' => $pickupId];
		}

		return $payload;
	}


}
